==> thunderbird_60.7.2.orig.tar.xz: thunderbird-60.7.2/widget/nsWidgetsCID.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

/* 2d96b3d0-c051-11d1-a827-0040959a28c9 */
#define NS_WINDOW_CID                                \
  {                                                  \
    0x2d96b3d0, 0xc051, 0x11d1, {                    \
      0xa8, 0x27, 0x00, 0x40, 0x95, 0x9a, 0x28, 0xc9 \
    }                                                \
  }

/* 2d96b3d1-c051-11d1-a827-0040959a28c9 */
#define NS_CHILD_CID                                 \
  {                                                  \
    0x2d96b3d1, 0xc051, 0x11d1, {                    \
      0xa8, 0x27, 0x00, 0x40, 0x95, 0x9a, 0x28, 0xc9 \
    }                                                \
  }

/* BA7DE611-6088-11d3-A83E-00105A183419 */
#define NS_POPUP_CID                                \
  {                                                 \
    0xba7de611, 0x6088, 0x11d3, {                   \
      0xa8, 0x3e, 0x0, 0x10, 0x5a, 0x18, 0x34, 0x19 \
    }                                               \
  }

/* bd57cee8-1dd1-11b2-9fe7-95cf4709aea3 */
#define NS_FILEPICKER_CID                            \
  {                                                  \
    0xbd57cee8, 0x1dd1, 0x11b2, {                    \
      0x9f, 0xe7, 0x95, 0xcf, 0x47, 0x09, 0xae, 0xa3 \
    }                                                \
  }

/* e221df9b-3d66-4045-9a66-5720949f8d10 */
#define NS_APPLICATIONCHOOSER_CID                    \
  {                                                  \
    0xe221df9b, 0x3d66, 0x4045, {                    \
      0x9a, 0x66, 0x57, 0x20, 0x94, 0x9f, 0x8d, 0x10 \
    }                                                \
  }

/* 0f872c8c-3ee6-46bd-92a2-69652c6b474e */
#define NS_COLORPICKER_CID                           \
  {                                                  \
    0x0f872c8c, 0x3ee6, 0x46bd, {                    \
      0x92, 0xa2, 0x69, 0x65, 0x2c, 0x6b, 0x47, 0x4e \
    }                                                \
  }

/* 2d96b3df-c051-11d1-a827-0040959a28c9 */
#define NS_APPSHELL_CID                              \
  {                                                  \
    0x2d96b3df, 0xc051, 0x11d1, {                    \
      0xa8, 0x27, 0x00, 0x40, 0x95, 0x9a, 0x28, 0xc9 \
    }                                                \
  }

/* 2d96b3e0-c051-11d1-a827-0040959a28c9 */
#define NS_TOOLKIT_CID                               \
  {                                                  \
    0x2d96b3e0, 0xc051, 0x11d1, {                    \
      0xa8, 0x27, 0x00, 0x40, 0x95, 0x9a, 0x28, 0xc9 \
    }                                                \
  }

/* 9A0CB62B-D638-4FAF-9588-AE96F5E29093 */
#define NS_TASKBARPREVIEWCALLBACK_CID                \
  {                                                  \
    0x9a0cb62b, 0xd638, 0x4faf, {                    \
      0x95, 0x88, 0xae, 0x96, 0xf5, 0xe2, 0x90, 0x93 \
    }                                                \
  }

/* XXX the following CID's are not in order. This needs
   to be fixed. */

//-----------------------------------------------------------
// Menus
//-----------------------------------------------------------

// {0B3FE5AA-BC72-4303-85AE-76365DF1251D}
#define NS_NATIVEMENUSERVICE_CID                     \
  {                                                  \
    0x0B3FE5AA, 0xBC72, 0x4303, {                    \
      0x85, 0xAE, 0x76, 0x36, 0x5D, 0xF1, 0x25, 0x1D \
    }                                                \
  }

// {F6CD4F21-53AF-11d2-8DC4-00609703C14E}
#define NS_POPUPMENU_CID                           \
  {                                                \
    0xf6cd4f21, 0x53af, 0x11d2, {                  \
      0x8d, 0xc4, 0x0, 0x60, 0x97, 0x3, 0xc1, 0x4e \
    }                                              \
  }

// {1F39AE50-B6A0-4B37-90F4-60AF614193D8}
#define NS_STANDALONENATIVEMENU_CID                  \
  {                                                  \
    0x1F39AE50, 0xB6A0, 0x4B37, {                    \
      0x90, 0xF4, 0x60, 0xAF, 0x61, 0x41, 0x93, 0xD8 \
    }                                                \
  }

// {2451BAED-8DC3-46D9-9E30-96E1BAA03666}
#define NS_MACDOCKSUPPORT_CID                        \
  {                                                  \
    0x2451BAED, 0x8DC3, 0x46D9, {                    \
      0x9E, 0x30, 0x96, 0xE1, 0xBA, 0xA0, 0x36, 0x66 \
    }                                                \
  }

// {b6e1a890-b2b8-4883-a65f-9476f6185313}
#define NS_MACSYSTEMSTATUSBAR_CID                    \
  {                                                  \
    0xb6e1a890, 0xb2b8, 0x4883, {                    \
      0xa6, 0x5f, 0x94, 0x76, 0xf6, 0x18, 0x53, 0x13 \
    }                                                \
  }

//-----------------------------------------------------------
// Drag & Drop & Clipboard
//-----------------------------------------------------------
// {8B5314BB-DB01-11d2-96CE-0060B0FB9956}
#define NS_DRAGSERVICE_CID                          \
  {                                                 \
    0x8b5314bb, 0xdb01, 0x11d2, {                   \
      0x96, 0xce, 0x0, 0x60, 0xb0, 0xfb, 0x99, 0x56 \
    }                                               \
  }

// {8B5314BC-DB01-11d2-96CE-0060B0FB9956}
#define NS_TRANSFERABLE_CID                         \
  {                                                 \
    0x8b5314bc, 0xdb01, 0x11d2, {                   \
      0x96, 0xce, 0x0, 0x60, 0xb0, 0xfb, 0x99, 0x56 \
    }                                               \
  }

// {8B5314BA-DB01-11d2-96CE-0060B0FB9956}
#define NS_CLIPBOARD_CID                            \
  {                                                 \
    0x8b5314ba, 0xdb01, 0x11d2, {                   \
      0x96, 0xce, 0x0, 0x60, 0xb0, 0xfb, 0x99, 0x56 \
    }                                               \
  }

// {77221D5A-1DD2-11B2-8C69-C710F15D2ED5}
#define NS_CLIPBOARDHELPER_CID                       \
  {                                                  \
    0x77221d5a, 0x1dd2, 0x11b2, {                    \
      0x8c, 0x69, 0xc7, 0x10, 0xf1, 0x5d, 0x2e, 0xd5 \
    }                                                \
  }

// {8B5314BD-DB01-11d2-96CE-0060B0FB9956}
#define NS_DATAFLAVOR_CID                           \
  {                                                 \
    0x8b5314bd, 0xdb01, 0x11d2, {                   \
      0x96, 0xce, 0x0, 0x60, 0xb0, 0xfb, 0x99, 0x56 \
    }                                               \
  }

// {948A0023-E3A7-11d2-96CF-0060B0FB9956}
#define NS_HTMLFORMATCONVERTER_CID                  \
  {                                                 \
    0x948a0023, 0xe3a7, 0x11d2, {                   \
      0x96, 0xcf, 0x0, 0x60, 0xb0, 0xfb, 0x99, 0x56 \
    }                                               \
  }

//-----------------------------------------------------------
// Other
//-----------------------------------------------------------
// {B148EED2-236D-11d3-B35C-00A0CC3C1CDE}
#define NS_SOUND_CID                                \
  {                                                 \
    0xb148eed2, 0x236d, 0x11d3, {                   \
      0xb3, 0x5c, 0x0, 0xa0, 0xcc, 0x3c, 0x1c, 0xde \
    }                                               \
  }

// {9f1800ab-f428-4207-b40c-e832e77b01fc}
#define NS_BIDIKEYBOARD_CID                          \
  {                                                  \
    0x9f1800ab, 0xf428, 0x4207, {                    \
      0xb4, 0x0c, 0xe8, 0x32, 0xe7, 0x7b, 0x01, 0xfc \
    }                                                \
  }

#define PUPPETBIDIKEYBOARD_CID                       \
  {                                                  \
    0x689e2586, 0x0344, 0x40b2, {                    \
      0x83, 0x75, 0x13, 0x67, 0x2d, 0x3b, 0x71, 0x9a \
    }                                                \
  }

#define NS_SCREENMANAGER_CID                         \
  {                                                  \
    0xc401eb80, 0xf9ea, 0x11d3, {                    \
      0xbb, 0x6f, 0xe7, 0x32, 0xb7, 0x3e, 0xbe, 0x7c \
    }                                                \
  }

// {6987230e-0089-4e78-bc5f-1493ee7519fa}
#define NS_IDLE_SERVICE_CID                          \
  {                                                  \
    0x6987230e, 0x0098, 0x4e78, {                    \
      0xbc, 0x5f, 0x14, 0x93, 0xee, 0x75, 0x19, 0xfa \
    }                                                \
  }

#define NS_WIN_TASKBAR_CID                           \
  {                                                  \
    0xb8e5bc54, 0xa22f, 0x4eb2, {                    \
      0xb0, 0x61, 0x24, 0xcb, 0x6d, 0x19, 0xc1, 0x5f \
    }                                                \
  }

// {73A5946F-608D-454f-9D33-0B8F8C7294B6}
#define NS_WIN_JUMPLISTBUILDER_CID                  \
  {                                                 \
    0x73a5946f, 0x608d, 0x454f, {                   \
      0x9d, 0x33, 0xb, 0x8f, 0x8c, 0x72, 0x94, 0xb6 \
    }                                               \
  }

// {2B9A1F2C-27CE-45b6-8D4E-755D0E34F8DB}
#define NS_WIN_JUMPLISTITEM_CID                      \
  {                                                  \
    0x2b9a1f2c, 0x27ce, 0x45b6, {                    \
      0x8d, 0x4e, 0x75, 0x5d, 0x0e, 0x34, 0xf8, 0xdb \
    }                                                \
  }

// {21F1F13B-F75A-42ad-867A-D91AD694447E}
#define NS_WIN_JUMPLISTSEPARATOR_CID                 \
  {                                                  \
    0x21f1f13b, 0xf75a, 0x42ad, {                    \
      0x86, 0x7a, 0xd9, 0x1a, 0xd6, 0x94, 0x44, 0x7e \
    }                                                \
  }

// {F72C5DC4-5A12-47be-BE28-AB105F33B08F}
#define NS_WIN_JUMPLISTLINK_CID                      \
  {                                                  \
    0xf72c5dc4, 0x5a12, 0x47be, {                    \
      0xbe, 0x28, 0xab, 0x10, 0x5f, 0x33, 0xb0, 0x8f \
    }                                                \
  }

// {B16656B2-5187-498f-ABF4-56346126BFDB}
#define NS_WIN_JUMPLISTSHORTCUT_CID                  \
  {                                                  \
    0xb16656b2, 0x5187, 0x498f, {                    \
      0xab, 0xf4, 0x56, 0x34, 0x61, 0x26, 0xbf, 0xdb \
    }                                                \
  }

// {e9096367-ddd9-45e4-b762-49c0c18b7119}
#define NS_MACWEBAPPUTILS_CID                        \
  {                                                  \
    0xe9096367, 0xddd9, 0x45e4, {                    \
      0xb7, 0x62, 0x49, 0xc0, 0xc1, 0x8b, 0x71, 0x19 \
    }                                                \
  }

//-----------------------------------------------------------
// Printing
//-----------------------------------------------------------
#define NS_DEVICE_CONTEXT_SPEC_CID                   \
  {                                                  \
    0xd3f69889, 0xe13a, 0x4321, {                    \
      0x98, 0x0c, 0xa3, 0x93, 0x32, 0xe2, 0x1f, 0x34 \
    }                                                \
  }

#define NS_PRINTSETTINGSSERVICE_CID                  \
  {                                                  \
    0x841387c8, 0x72e6, 0x484b, {                    \
      0x92, 0x96, 0xbf, 0x6e, 0xea, 0x80, 0xd5, 0x8a \
    }                                                \
  }

#define NS_PRINTER_ENUMERATOR_CID                    \
  {                                                  \
    0xa6cf9129, 0x15b3, 0x11d2, {                    \
      0x93, 0x2e, 0x00, 0x80, 0x5f, 0x8a, 0xdd, 0x32 \
    }                                                \
  }

#define NS_PRINTSESSION_CID                          \
  {                                                  \
    0x2f977d53, 0x5485, 0x11d4, {                    \
      0x87, 0xe2, 0x00, 0x10, 0xa4, 0xe7, 0x5e, 0xf2 \
    }                                                \
  }

#define NS_PRINTDIALOGSERVICE_CID                    \
  {                                                  \
    0x06beec76, 0xa183, 0x4d9f, {                    \
      0x85, 0xdd, 0x08, 0x5f, 0x26, 0xda, 0x56, 0x5a \
    }                                                \
  }

#define NS_GFXINFO_CID                               \
  {                                                  \
    0xd755a760, 0x9f27, 0x11df, {                    \
      0x08, 0x00, 0x20, 0x0c, 0x9a, 0x66, 0x42, 0x42 \
    }                                                \
  }

#define NS_WINDOWS_UIUTILS_CID                       \
  {                                                  \
    0xe04a55e8, 0xfee3, 0x4ea2, {                    \
      0xa9, 0x8b, 0x41, 0xd2, 0x62, 0x1a, 0xdc, 0x3c \
    }                                                \
  }

==> thunderbird_68.9.0.orig.tar.xz: thunderbird-68.9.0/widget/nsWidgetsCID.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

/* bd57cee8-1dd1-11b2-9fe7-95cf4709aea3 */
#define NS_FILEPICKER_CID                            \
  {                                                  \
    0xbd57cee8, 0x1dd1, 0x11b2, {                    \
      0x9f, 0xe7, 0x95, 0xcf, 0x47, 0x09, 0xae, 0xa3 \
    }                                                \
  }

/* e221df9b-3d66-4045-9a66-5720949f8d10 */
#define NS_APPLICATIONCHOOSER_CID                    \
  {                                                  \
    0xe221df9b, 0x3d66, 0x4045, {                    \
      0x9a, 0x66, 0x57, 0x20, 0x94, 0x9f, 0x8d, 0x10 \
    }                                                \
  }

/* 0f872c8c-3ee6-46bd-92a2-69652c6b474e */
#define NS_COLORPICKER_CID                           \
  {                                                  \
    0x0f872c8c, 0x3ee6, 0x46bd, {                    \
      0x92, 0xa2, 0x69, 0x65, 0x2c, 0x6b, 0x47, 0x4e \
    }                                                \
  }

/* 2d96b3df-c051-11d1-a827-0040959a28c9 */
#define NS_APPSHELL_CID                              \
  {                                                  \
    0x2d96b3df, 0xc051, 0x11d1, {                    \
      0xa8, 0x27, 0x00, 0x40, 0x95, 0x9a, 0x28, 0xc9 \
    }                                                \
  }

/* 2d96b3e0-c051-11d1-a827-0040959a28c9 */
#define NS_TOOLKIT_CID                               \
  {                                                  \
    0x2d96b3e0, 0xc051, 0x11d1, {                    \
      0xa8, 0x27, 0x00, 0x40, 0x95, 0x9a, 0x28, 0xc9 \
    }                                                \
  }

/* 9A0CB62B-D638-4FAF-9588-AE96F5E29093 */
#define NS_TASKBARPREVIEWCALLBACK_CID                \
  {                                                  \
    0x9a0cb62b, 0xd638, 0x4faf, {                    \
      0x95, 0x88, 0xae, 0x96, 0xf5, 0xe2, 0x90, 0x93 \
    }                                                \
  }

/* XXX the following CID's are not in order. This needs
   to be fixed. */

//-----------------------------------------------------------
// Menus
//-----------------------------------------------------------

// {0B3FE5AA-BC72-4303-85AE-76365DF1251D}
#define NS_NATIVEMENUSERVICE_CID                     \
  {                                                  \
    0x0B3FE5AA, 0xBC72, 0x4303, {                    \
      0x85, 0xAE, 0x76, 0x36, 0x5D, 0xF1, 0x25, 0x1D \
    }                                                \
  }

// {F6CD4F21-53AF-11d2-8DC4-00609703C14E}
#define NS_POPUPMENU_CID                           \
  {                                                \
    0xf6cd4f21, 0x53af, 0x11d2, {                  \
      0x8d, 0xc4, 0x0, 0x60, 0x97, 0x3, 0xc1, 0x4e \
    }                                              \
  }

// {1F39AE50-B6A0-4B37-90F4-60AF614193D8}
#define NS_STANDALONENATIVEMENU_CID                  \
  {                                                  \
    0x1F39AE50, 0xB6A0, 0x4B37, {                    \
      0x90, 0xF4, 0x60, 0xAF, 0x61, 0x41, 0x93, 0xD8 \
    }                                                \
  }

// {2451BAED-8DC3-46D9-9E30-96E1BAA03666}
#define NS_MACDOCKSUPPORT_CID                        \
  {                                                  \
    0x2451BAED, 0x8DC3, 0x46D9, {                    \
      0x9E, 0x30, 0x96, 0xE1, 0xBA, 0xA0, 0x36, 0x66 \
    }                                                \
  }

// {de59fe1a-46c8-490f-b04d-34545acb06c9}
#define NS_MACSHARINGSERVICE_CID                     \
  {                                                  \
    0xde59fe1a, 0x46c8, 0x490f, {                    \
      0xb0, 0x4d, 0x34, 0x54, 0x5a, 0xcb, 0x06, 0xc9 \
    }                                                \
  }

// {b6e1a890-b2b8-4883-a65f-9476f6185313}
#define NS_MACSYSTEMSTATUSBAR_CID                    \
  {                                                  \
    0xb6e1a890, 0xb2b8, 0x4883, {                    \
      0xa6, 0x5f, 0x94, 0x76, 0xf6, 0x18, 0x53, 0x13 \
    }                                                \
  }

// {ea109912-3acc-48de-b679-c23b6a122da5}
#define NS_TOUCHBARHELPER_CID                        \
  {                                                  \
    0xea109912, 0x3acc, 0x48de, {                    \
      0xb6, 0x79, 0xc2, 0x3b, 0x6a, 0x12, 0x2d, 0xa5 \
    }                                                \
  }

// {38f396e2-93c9-4a77-aaf7-2d50b9962186}
#define NS_TOUCHBARUPDATER_CID                       \
  {                                                  \
    0x38f396e2, 0x93c9, 0x4a77, {                    \
      0xaa, 0xf7, 0x2d, 0x50, 0xb9, 0x96, 0x21, 0x86 \
    }                                                \
  }

// {77441d17-f29c-49d7-982f-f20a5ab5a900}
#define NS_TOUCHBARINPUT_CID                         \
  {                                                  \
    0x77441d17, 0xf29c, 0x49d7, {                    \
      0x98, 0x2f, 0xf2, 0x0a, 0x5a, 0xb5, 0xa9, 0x00 \
    }                                                \
  }

//-----------------------------------------------------------
// Drag & Drop & Clipboard
//-----------------------------------------------------------
// {8B5314BB-DB01-11d2-96CE-0060B0FB9956}
#define NS_DRAGSERVICE_CID                          \
  {                                                 \
    0x8b5314bb, 0xdb01, 0x11d2, {                   \
      0x96, 0xce, 0x0, 0x60, 0xb0, 0xfb, 0x99, 0x56 \
    }                                               \
  }

// {8B5314BC-DB01-11d2-96CE-0060B0FB9956}
#define NS_TRANSFERABLE_CID                         \
  {                                                 \
    0x8b5314bc, 0xdb01, 0x11d2, {                   \
      0x96, 0xce, 0x0, 0x60, 0xb0, 0xfb, 0x99, 0x56 \
    }                                               \
  }

// {8B5314BA-DB01-11d2-96CE-0060B0FB9956}
#define NS_CLIPBOARD_CID                            \
  {                                                 \
    0x8b5314ba, 0xdb01, 0x11d2, {                   \
      0x96, 0xce, 0x0, 0x60, 0xb0, 0xfb, 0x99, 0x56 \
    }                                               \
  }

// {77221D5A-1DD2-11B2-8C69-C710F15D2ED5}
#define NS_CLIPBOARDHELPER_CID                       \
  {                                                  \
    0x77221d5a, 0x1dd2, 0x11b2, {                    \
      0x8c, 0x69, 0xc7, 0x10, 0xf1, 0x5d, 0x2e, 0xd5 \
    }                                                \
  }

// {8B5314BD-DB01-11d2-96CE-0060B0FB9956}
#define NS_DATAFLAVOR_CID                           \
  {                                                 \
    0x8b5314bd, 0xdb01, 0x11d2, {                   \
      0x96, 0xce, 0x0, 0x60, 0xb0, 0xfb, 0x99, 0x56 \
    }                                               \
  }

// {948A0023-E3A7-11d2-96CF-0060B0FB9956}
#define NS_HTMLFORMATCONVERTER_CID                  \
  {                                                 \
    0x948a0023, 0xe3a7, 0x11d2, {                   \
      0x96, 0xcf, 0x0, 0x60, 0xb0, 0xfb, 0x99, 0x56 \
    }                                               \
  }

//-----------------------------------------------------------
// Other
//-----------------------------------------------------------
// {B148EED2-236D-11d3-B35C-00A0CC3C1CDE}
#define NS_SOUND_CID                                \
  {                                                 \
    0xb148eed2, 0x236d, 0x11d3, {                   \
      0xb3, 0x5c, 0x0, 0xa0, 0xcc, 0x3c, 0x1c, 0xde \
    }                                               \
  }

#define NS_SCREENMANAGER_CID                         \
  {                                                  \
    0xc401eb80, 0xf9ea, 0x11d3, {                    \
      0xbb, 0x6f, 0xe7, 0x32, 0xb7, 0x3e, 0xbe, 0x7c \
    }                                                \
  }

// {6987230e-0089-4e78-bc5f-1493ee7519fa}
#define NS_IDLE_SERVICE_CID                          \
  {                                                  \
    0x6987230e, 0x0098, 0x4e78, {                    \
      0xbc, 0x5f, 0x14, 0x93, 0xee, 0x75, 0x19, 0xfa \
    }                                                \
  }

#define NS_WIN_TASKBAR_CID                           \
  {                                                  \
    0xb8e5bc54, 0xa22f, 0x4eb2, {                    \
      0xb0, 0x61, 0x24, 0xcb, 0x6d, 0x19, 0xc1, 0x5f \
    }                                                \
  }

// {73A5946F-608D-454f-9D33-0B8F8C7294B6}
#define NS_WIN_JUMPLISTBUILDER_CID                  \
  {                                                 \
    0x73a5946f, 0x608d, 0x454f, {                   \
      0x9d, 0x33, 0xb, 0x8f, 0x8c, 0x72, 0x94, 0xb6 \
    }                                               \
  }

// {2B9A1F2C-27CE-45b6-8D4E-755D0E34F8DB}
#define NS_WIN_JUMPLISTITEM_CID                      \
  {                                                  \
    0x2b9a1f2c, 0x27ce, 0x45b6, {                    \
      0x8d, 0x4e, 0x75, 0x5d, 0x0e, 0x34, 0xf8, 0xdb \
    }                                                \
  }

// {21F1F13B-F75A-42ad-867A-D91AD694447E}
#define NS_WIN_JUMPLISTSEPARATOR_CID                 \
  {                                                  \
    0x21f1f13b, 0xf75a, 0x42ad, {                    \
      0x86, 0x7a, 0xd9, 0x1a, 0xd6, 0x94, 0x44, 0x7e \
    }                                                \
  }

// {F72C5DC4-5A12-47be-BE28-AB105F33B08F}
#define NS_WIN_JUMPLISTLINK_CID                      \
  {                                                  \
    0xf72c5dc4, 0x5a12, 0x47be, {                    \
      0xbe, 0x28, 0xab, 0x10, 0x5f, 0x33, 0xb0, 0x8f \
    }                                                \
  }

// {B16656B2-5187-498f-ABF4-56346126BFDB}
#define NS_WIN_JUMPLISTSHORTCUT_CID                  \
  {                                                  \
    0xb16656b2, 0x5187, 0x498f, {                    \
      0xab, 0xf4, 0x56, 0x34, 0x61, 0x26, 0xbf, 0xdb \
    }                                                \
  }

// {e9096367-ddd9-45e4-b762-49c0c18b7119}
#define NS_MACWEBAPPUTILS_CID                        \
  {                                                  \
    0xe9096367, 0xddd9, 0x45e4, {                    \
      0xb7, 0x62, 0x49, 0xc0, 0xc1, 0x8b, 0x71, 0x19 \
    }                                                \
  }

// {a9339876-0027-430f-b953-84c9c11c2da3}
#define NS_GTK_TASKBARPROGRESS_CID                   \
  {                                                  \
    0xa9339876, 0x0027, 0x430f, {                    \
      0xb9, 0x53, 0x84, 0xc9, 0xc1, 0x1c, 0x2d, 0xa3 \
    }                                                \
  }

//-----------------------------------------------------------
// Printing
//-----------------------------------------------------------
#define NS_DEVICE_CONTEXT_SPEC_CID                   \
  {                                                  \
    0xd3f69889, 0xe13a, 0x4321, {                    \
      0x98, 0x0c, 0xa3, 0x93, 0x32, 0xe2, 0x1f, 0x34 \
    }                                                \
  }

#define NS_PRINTSETTINGSSERVICE_CID                  \
  {                                                  \
    0x841387c8, 0x72e6, 0x484b, {                    \
      0x92, 0x96, 0xbf, 0x6e, 0xea, 0x80, 0xd5, 0x8a \
    }                                                \
  }

#define NS_PRINTER_ENUMERATOR_CID                    \
  {                                                  \
    0xa6cf9129, 0x15b3, 0x11d2, {                    \
      0x93, 0x2e, 0x00, 0x80, 0x5f, 0x8a, 0xdd, 0x32 \
    }                                                \
  }

#define NS_PRINTSESSION_CID                          \
  {                                                  \
    0x2f977d53, 0x5485, 0x11d4, {                    \
      0x87, 0xe2, 0x00, 0x10, 0xa4, 0xe7, 0x5e, 0xf2 \
    }                                                \
  }

#define NS_PRINTDIALOGSERVICE_CID                    \
  {                                                  \
    0x06beec76, 0xa183, 0x4d9f, {                    \
      0x85, 0xdd, 0x08, 0x5f, 0x26, 0xda, 0x56, 0x5a \
    }                                                \
  }

#define NS_GFXINFO_CID                               \
  {                                                  \
    0xd755a760, 0x9f27, 0x11df, {                    \
      0x08, 0x00, 0x20, 0x0c, 0x9a, 0x66, 0x42, 0x42 \
    }                                                \
  }

#define NS_WINDOWS_UIUTILS_CID                       \
  {                                                  \
    0xe04a55e8, 0xfee3, 0x4ea2, {                    \
      0xa9, 0x8b, 0x41, 0xd2, 0x62, 0x1a, 0xdc, 0x3c \
    }                                                \
  }
